==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/RuleGroupCustomResponseBodyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.RuleGroupCustomResponseBodyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property content The payload of the custom response.
 * @property contentType The type of content in the payload that you are defining in the `content` argument. Valid values are `TEXT_PLAIN`, `TEXT_HTML`, or `APPLICATION_JSON`.
 * @property key A unique key identifying the custom response body. This is referenced by the `custom_response_body_key` argument in the Custom Response block.
 */
public data class RuleGroupCustomResponseBodyArgs(
    public val content: Output<String>,
    public val contentType: Output<String>,
    public val key: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.wafv2.inputs.RuleGroupCustomResponseBodyArgs> {
    override fun toJava(): com.pulumi.aws.wafv2.inputs.RuleGroupCustomResponseBodyArgs =
        com.pulumi.aws.wafv2.inputs.RuleGroupCustomResponseBodyArgs.builder()
            .content(content.applyValue({ args0 -> args0 }))
            .contentType(contentType.applyValue({ args0 -> args0 }))
            .key(key.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RuleGroupCustomResponseBodyArgs].
 */
@PulumiTagMarker
public class RuleGroupCustomResponseBodyArgsBuilder internal constructor() {
    private var content: Output<String>? = null

    private var contentType: Output<String>? = null

    private var key: Output<String>? = null

    /**
     * @param value The payload of the custom response.
     */
    @JvmName("hbnowpgrjytvtnkp")
    public suspend fun content(`value`: Output<String>) {
        this.content = value
    }

    /**
     * @param value The type of content in the payload that you are defining in the `content` argument. Valid values are `TEXT_PLAIN`, `TEXT_HTML`, or `APPLICATION_JSON`.
     */
    @JvmName("escsfexxlywbeuud")
    public suspend fun contentType(`value`: Output<String>) {
        this.contentType = value
    }

    /**
     * @param value A unique key identifying the custom response body. This is referenced by the `custom_response_body_key` argument in the Custom Response block.
     */
    @JvmName("vhuighgeafytqjkn")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The payload of the custom response.
     */
    @JvmName("qcjjbpccrcxfjgqm")
    public suspend fun content(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.content = mapped
    }

    /**
     * @param value The type of content in the payload that you are defining in the `content` argument. Valid values are `TEXT_PLAIN`, `TEXT_HTML`, or `APPLICATION_JSON`.
     */
    @JvmName("ccnxuoculxlhwhml")
    public suspend fun contentType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.contentType = mapped
    }

    /**
     * @param value A unique key identifying the custom response body. This is referenced by the `custom_response_body_key` argument in the Custom Response block.
     */
    @JvmName("mperhgstbuxiuquu")
    public suspend fun key(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.key = mapped
    }

    internal fun build(): RuleGroupCustomResponseBodyArgs = RuleGroupCustomResponseBodyArgs(
        content = content ?: throw PulumiNullFieldException("content"),
        contentType = contentType ?: throw PulumiNullFieldException("contentType"),
        key = key ?: throw PulumiNullFieldException("key"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/RuleGroupCustomResponseBodyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.RuleGroupCustomResponseBodyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property content The payload of the custom response.
 * @property contentType The type of content in the payload that you are defining in the `content` argument. Valid values are `TEXT_PLAIN`, `TEXT_HTML`, or `APPLICATION_JSON`.
 * @property key A unique key identifying the custom response body. This is referenced by the `custom_response_body_key` argument in the Custom Response block.
 */
public data class RuleGroupCustomResponseBodyArgs(
    public val content: Output<String>,
    public val contentType: Output<String>,
    public val key: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.wafv2.inputs.RuleGroupCustomResponseBodyArgs> {
    override fun toJava(): com.pulumi.aws.wafv2.inputs.RuleGroupCustomResponseBodyArgs =
        com.pulumi.aws.wafv2.inputs.RuleGroupCustomResponseBodyArgs.builder()
            .content(content.applyValue({ args0 -> args0 }))
            .contentType(contentType.applyValue({ args0 -> args0 }))
            .key(key.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RuleGroupCustomResponseBodyArgs].
 */
@PulumiTagMarker
public class RuleGroupCustomResponseBodyArgsBuilder internal constructor() {
    private var content: Output<String>? = null

    private var contentType: Output<String>? = null

    private var key: Output<String>? = null

    /**
     * @param value The payload of the custom response.
     */
    @JvmName("iallwnvsqlpelgix")
    public suspend fun content(`value`: Output<String>) {
        this.content = value
    }

    /**
     * @param value The type of content in the payload that you are defining in the `content` argument. Valid values are `TEXT_PLAIN`, `TEXT_HTML`, or `APPLICATION_JSON`.
     */
    @JvmName("ireeqokfbmfrojmv")
    public suspend fun contentType(`value`: Output<String>) {
        this.contentType = value
    }

    /**
     * @param value A unique key identifying the custom response body. This is referenced by the `custom_response_body_key` argument in the Custom Response block.
     */
    @JvmName("piryhcouhfjcsymd")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The payload of the custom response.
     */
    @JvmName("wnfkqfketdakpgka")
    public suspend fun content(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.content = mapped
    }

    /**
     * @param value The type of content in the payload that you are defining in the `content` argument. Valid values are `TEXT_PLAIN`, `TEXT_HTML`, or `APPLICATION_JSON`.
     */
    @JvmName("qrcahblqiepvvcmm")
    public suspend fun contentType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.contentType = mapped
    }

    /**
     * @param value A unique key identifying the custom response body. This is referenced by the `custom_response_body_key` argument in the Custom Response block.
     */
    @JvmName("pfvwywtbrwcdyldk")
    public suspend fun key(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.key = mapped
    }

    internal fun build(): RuleGroupCustomResponseBodyArgs = RuleGroupCustomResponseBodyArgs(
        content = content ?: throw PulumiNullFieldException("content"),
        contentType = contentType ?: throw PulumiNullFieldException("contentType"),
        key = key ?: throw PulumiNullFieldException("key"),
    )
}
